@@ -33,7 +33,7 @@
  * An IBusEngine provides infrastructure for input method engine.
  * Developers can "extend" this class for input method engine development.
  *
- * @see_also: #IBusComponent, #IBusEngineDesc
+ * see_also: #IBusComponent, #IBusEngineDesc
  */
 #ifndef __IBUS_ENGINE_H_
 #define __IBUS_ENGINE_H_
@@ -158,8 +158,8 @@ GType        ibus_engine_get_type       (void);
 
 /**
  * ibus_engine_new:
- * @name: Name of the IBusObject.
- * @path: Path for IBusService.
+ * @engine_name: Name of the IBusObject.
+ * @object_path: Path for IBusService.
  * @connection: An opened GDBusConnection.
  * @returns: A newly allocated IBusEngine.
  *
@@ -169,8 +169,8 @@ IBusEngine  *ibus_engine_new            (const gchar        *engine_name,
                                          const gchar        *object_path,
                                          GDBusConnection    *connection);
 /**
- * ibus_engine_new_type:
- * @engine_type: GType of subclass of IBUS_TYPE_ENGINE
+ * ibus_engine_new_with_type:
+ * @engine_type: GType of #IBusEngine.
  * @engine_name: Name of the IBusObject.
  * @object_path: Path for IBusService.
  * @connection: An opened GDBusConnection.
@@ -178,7 +178,7 @@ IBusEngine  *ibus_engine_new            (const gchar        *engine_name,
  *
  * New an IBusEngine.
  */
-IBusEngine  *ibus_engine_new_type       (GType               engine_type,
+IBusEngine  *ibus_engine_new_with_type  (GType               engine_type,
                                          const gchar        *engine_name,
                                          const gchar        *object_path,
                                          GDBusConnection    *connection);
@@ -225,10 +225,14 @@ void         ibus_engine_update_preedit_text
  * @visible: Whether the pre-edit buffer is visible.
  * @mode: Pre-edit commit mode when the focus is lost.
  *
- * Update the pre-edit buffer with commit mode.
- * if mode is IBUS_ENGINE_PREEDIT_CLEAR,
- * ibus_engine_update_preedit_text_with_mode is compatible with
- * ibus_engine_update_preedit_text.
+ * Update the pre-edit buffer with commit mode. Similar to
+ * ibus_engine_update_preedit_text(), this function allows users to specify
+ * the behavior on focus out when the pre-edit buffer is visible.
+ *
+ * If @mode is IBUS_ENGINE_PREEDIT_COMMIT, contents of the pre-edit buffer
+ * will be comitted and cleared.
+ * If @mode is IBUS_ENGINE_PREEDIT_CLEAR, contents of the pre-edit buffer
+ * will be cleared only.
  *
  * (Note: The text object will be released, if it is floating.
  *  If caller want to keep the object, caller should make the object
@@ -408,9 +412,9 @@ void ibus_engine_delete_surrounding_text(IBusEngine         *engine,
 /**
  * ibus_engine_get_surrounding_text:
  * @engine: An IBusEngine.
- * @text: (allow-none): Location to store surrounding text.
- * @cursor_pos: (allow-none): Cursor position in characters in @text.
- * @anchor_pos: (allow-none): Anchor position of selection in @text.
+ * @text: (out) (transfer none) (allow-none): Location to store surrounding text.
+ * @cursor_pos: (out) (allow-none): Cursor position in characters in @text.
+ * @anchor_pos: (out) (allow-none): Anchor position of selection in @text.
  *
  * Get surrounding text.
  *
@@ -419,7 +423,7 @@ void ibus_engine_delete_surrounding_text(IBusEngine         *engine,
  * #IBusEngine::enable handler, with both @text and @cursor set to
  * %NULL.
  *
- * @see_also #IBusEngine::set-surrounding-text
+ * see_also #IBusEngine::set-surrounding-text
  */
 void ibus_engine_get_surrounding_text(IBusEngine         *engine,
                                       IBusText          **text,
